==> zio-aws-robomaker_3-5.17.129.1-sources.jar: zio/aws/robomaker/model/Compute.scala <==
package zio.aws.robomaker.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.robomaker.model.primitives.{GPUUnit, SimulationUnit}
import scala.jdk.CollectionConverters.*
final case class Compute(
    simulationUnitLimit: Option[SimulationUnit] = None,
    computeType: Option[zio.aws.robomaker.model.ComputeType] = None,
    gpuUnitLimit: Option[GPUUnit] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.Compute = {
    import Compute.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.Compute
      .builder()
      .optionallyWith(
        simulationUnitLimit.map(value => SimulationUnit.unwrap(value): Integer)
      )(_.simulationUnitLimit)
      .optionallyWith(computeType.map(value => value.unwrap))(_.computeType)
      .optionallyWith(
        gpuUnitLimit.map(value => GPUUnit.unwrap(value): Integer)
      )(_.gpuUnitLimit)
      .build()
  }
  def asReadOnly: zio.aws.robomaker.model.Compute.ReadOnly =
    zio.aws.robomaker.model.Compute.wrap(buildAwsValue())
}
object Compute {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.robomaker.model.Compute] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.Compute =
      zio.aws.robomaker.model.Compute(
        simulationUnitLimit.map(value => value),
        computeType.map(value => value),
        gpuUnitLimit.map(value => value)
      )
    def simulationUnitLimit: Option[SimulationUnit]
    def computeType: Option[zio.aws.robomaker.model.ComputeType]
    def gpuUnitLimit: Option[GPUUnit]
    def getSimulationUnitLimit: ZIO[Any, AwsError, SimulationUnit] =
      AwsError.unwrapOptionField("simulationUnitLimit", simulationUnitLimit)
    def getComputeType
        : ZIO[Any, AwsError, zio.aws.robomaker.model.ComputeType] =
      AwsError.unwrapOptionField("computeType", computeType)
    def getGpuUnitLimit: ZIO[Any, AwsError, GPUUnit] =
      AwsError.unwrapOptionField("gpuUnitLimit", gpuUnitLimit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.Compute
  ) extends zio.aws.robomaker.model.Compute.ReadOnly {
    override val simulationUnitLimit: Option[SimulationUnit] = scala
      .Option(impl.simulationUnitLimit())
      .map(value => zio.aws.robomaker.model.primitives.SimulationUnit(value))
    override val computeType: Option[zio.aws.robomaker.model.ComputeType] =
      scala
        .Option(impl.computeType())
        .map(value => zio.aws.robomaker.model.ComputeType.wrap(value))
    override val gpuUnitLimit: Option[GPUUnit] = scala
      .Option(impl.gpuUnitLimit())
      .map(value => zio.aws.robomaker.model.primitives.GPUUnit(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.Compute
  ): zio.aws.robomaker.model.Compute.ReadOnly = new Wrapper(impl)
}

==> zio-aws-robomaker_3-6.20.78.1-sources.jar: zio/aws/robomaker/model/Compute.scala <==
package zio.aws.robomaker.model
import zio.aws.robomaker.model.primitives.{GPUUnit, SimulationUnit}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class Compute(
    simulationUnitLimit: Optional[SimulationUnit] = Optional.Absent,
    computeType: Optional[zio.aws.robomaker.model.ComputeType] =
      Optional.Absent,
    gpuUnitLimit: Optional[GPUUnit] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.Compute = {
    import Compute.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.Compute
      .builder()
      .optionallyWith(
        simulationUnitLimit.map(value => SimulationUnit.unwrap(value): Integer)
      )(_.simulationUnitLimit)
      .optionallyWith(computeType.map(value => value.unwrap))(_.computeType)
      .optionallyWith(
        gpuUnitLimit.map(value => GPUUnit.unwrap(value): Integer)
      )(_.gpuUnitLimit)
      .build()
  }
  def asReadOnly: zio.aws.robomaker.model.Compute.ReadOnly =
    zio.aws.robomaker.model.Compute.wrap(buildAwsValue())
}
object Compute {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.robomaker.model.Compute] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.Compute =
      zio.aws.robomaker.model.Compute(
        simulationUnitLimit.map(value => value),
        computeType.map(value => value),
        gpuUnitLimit.map(value => value)
      )
    def simulationUnitLimit: Optional[SimulationUnit]
    def computeType: Optional[zio.aws.robomaker.model.ComputeType]
    def gpuUnitLimit: Optional[GPUUnit]
    def getSimulationUnitLimit: ZIO[Any, AwsError, SimulationUnit] =
      AwsError.unwrapOptionField("simulationUnitLimit", simulationUnitLimit)
    def getComputeType
        : ZIO[Any, AwsError, zio.aws.robomaker.model.ComputeType] =
      AwsError.unwrapOptionField("computeType", computeType)
    def getGpuUnitLimit: ZIO[Any, AwsError, GPUUnit] =
      AwsError.unwrapOptionField("gpuUnitLimit", gpuUnitLimit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.Compute
  ) extends zio.aws.robomaker.model.Compute.ReadOnly {
    override val simulationUnitLimit: Optional[SimulationUnit] =
      zio.aws.core.internal
        .optionalFromNullable(impl.simulationUnitLimit())
        .map(value => zio.aws.robomaker.model.primitives.SimulationUnit(value))
    override val computeType: Optional[zio.aws.robomaker.model.ComputeType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.computeType())
        .map(value => zio.aws.robomaker.model.ComputeType.wrap(value))
    override val gpuUnitLimit: Optional[GPUUnit] = zio.aws.core.internal
      .optionalFromNullable(impl.gpuUnitLimit())
      .map(value => zio.aws.robomaker.model.primitives.GPUUnit(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.Compute
  ): zio.aws.robomaker.model.Compute.ReadOnly = new Wrapper(impl)
}
